#

##

##

    	barcode 2 eye

    	steps

    		[ ] byte string -> barcode
    			[ ] generate string for signing

    					{

    					}

    			[ ] UTF8 -> Byte string -> 2D (QR) code ->

    		[ ] [with camera] barcode -> byte string

    	important

    		https://pypi.org/project/pyzbar/

    		https://crates.io/crates/rxing
    		https://crates.io/crates/barcoders
    		https://crates.io/crates/dbr